@@ -1,5 +1,5 @@
 ;; -*- no-byte-compile: t; lexical-binding: nil -*-
-(define-package "transducers" "1.5.0"
+(define-package "transducers" "20251118.2154"
   "Ergonomic, efficient data processing."
   '((emacs "28.1"))
   :url "https://github.com/fosskers/transducers.el"
